@@ -69,7 +69,7 @@ class Span(ABC):
         self.logs = [
             Log(
                 items=[
-                    LogItem(key="Traceback", val=self.format_exc()),
+                    LogItem(key="Error", val=self.format_exc()),
                 ]
             )
         ]
